const piholeURL = `${import.meta.env.VITE_PIHOLE_URL}/api`

const piholeAuth = async () => {
    const session = await fetch(`${piholeURL}/auth`, {
        method: "POST",
        body: JSON.stringify({ "password": import.meta.env.VITE_PIHOLE_PASSWORD })
    })
        .then(response => {
            if (response.ok) {
                return response.json()
            }
            else console.log(response.status) && console.log(response.statusText)
        })
        .then(data => data.session)
        .catch(error => console.log(error))
    return session
}

const getRecords = async (session) => {
    const configDNS = await fetch(`${piholeURL}/config/dns/cnameRecords`, {
        method: "GET",
        headers: {"sid": session.sid}
    })
        .then(response => {
            if (response.ok) {
                return response.json()
            }
            else console.log(response.status) && console.log(response.statusText)
        })
        .then(data => {
            // console.log('getRecords: return data',data)
            return data

        })
        .catch(error => console.log(error))
    return {configDNS, session}
}

const makeRecord = async (data, session, fqdn, cnameTarget) => {
    const putRecord = await fetch(`${piholeURL}/config/dns/cnameRecords/${fqdn},${cnameTarget}`, {
        method: "PUT",
        headers: {"sid": session.sid}
    })
        .then(response => {
            if (response.status === 201){
                // console.log(`Response: ${response.status}`)
                return response.json()
            }
            if (!response.ok){
                // console.log(`Response: ${response.status} ${response.statusText}`)
                return response.json()
            }
            else console.log(response.status) && console.log(response.statusText)
        })
        .then(data => {
            if (data.error){console.log(data.error.message, data.error.hint)}
            return data
        })
        .catch(console.error)
    return putRecord
}

const pihole = (fqdn, cnameTarget) => {
    const pi = piholeAuth()
    pi.then(s => getRecords(s))
    .then((a) => {
        // console.log('pihole after getRecords', a.configDNS, a.session)
        makeRecord(a.configDNS, a.session, fqdn, cnameTarget)
    })
}
export default pihole